@@ -14,6 +14,7 @@ class Dispatcher(Process, Generic[S]):
         self.subscribers: "List[Queue[S]]" = []
         self._subscribers_mask: List[int] = []
         self._death_counter: List[int] = []
+        self._timeout = 0.1
 
         Timer(0.015, self.start).start()
 
@@ -25,7 +26,14 @@ class Dispatcher(Process, Generic[S]):
     def _dispatch(self, args: Iterable[S]):
         for s in self.subscribers:
             for arg in args:
-                s.put(arg)
+                while True:
+                    try:
+                        s.put(arg, timeout=self._timeout)
+                        break
+                    except Exception as e:
+                        if e.__class__.__name__ == "Full":
+                            pass
+                        break
 
     def _kill(self, packet: Any) -> bool:
         _, death_count = packet
@@ -39,19 +47,21 @@ class Dispatcher(Process, Generic[S]):
         for i, s in enumerate(self.subscribers):
             num_children = self._subscribers_mask[i]
             for _ in range(num_children):
-                s.put(GenericPipe.get_kill_word(num_children))
+                s.put(GenericPipe.get_kill_word(num_children), timeout=self._timeout)
         return True
 
     def run(self):
         while True:
             try:
-                packet = self._source.get()
+                packet = self._source.get(timeout=0.1)
                 if GenericPipe.is_death_packet(packet):
                     if self._kill(packet):
                         return
                     else:
                         continue
             except Exception as e:
+                if str(e.__class__) == "<class '_queue.Empty'>":
+                    continue
                 print("Error", e)
-                continue
+                return
             self._dispatch([packet])
