@@ -12,10 +12,10 @@ class FilterPipe(GenericPipe[R, R]):
         super().__init__(source, target)
         self._task = task
 
-    def perform_task(self, data: R) -> R:
+    def _perform_task(self, data: R) -> R:
         if self._task(data):
-            super().dispatch_to_next(data)
+            super()._send_to_next(data)
         return data
 
-    def dispatch_to_next(self, processed: R):
+    def _send_to_next(self, processed: R):
         pass
