@@ -15,7 +15,7 @@ class GenericPipe(Process, Generic[R, S]):
         super().__init__(daemon=True)
         self._source = source
         self._target = target
-        self._timeout: Optional[float] = None
+        self._timeout: Optional[float] = 0.1
         Timer(0.015, self.start).start()
 
     @staticmethod
@@ -36,19 +36,25 @@ class GenericPipe(Process, Generic[R, S]):
         try:
             self._source.close()
         except Exception:
-            pass
+            self.kill()
 
-    def _kill(self, data: Any):
-        while not self._target.empty():
-            time.sleep(0.01)
+    def _kill(self, data: Any, error: bool = False):
+        if error:
+            while not self._target.empty():
+                time.sleep(0.01)
         self._close_source()
         self._target.put(data)
 
-    def perform_task(self, data: R) -> S:
+    def _perform_task(self, data: R) -> S:
         return cast(S, data)
 
-    def dispatch_to_next(self, processed: S):
-        self._target.put(processed)
+    def _send_to_next(self, processed: S):
+        while True:
+            try:
+                self._target.put(processed, timeout=self._timeout)
+                break
+            except Exception as e:
+                pass
 
     def run(self):
         while True:
@@ -57,9 +63,11 @@ class GenericPipe(Process, Generic[R, S]):
                 if GenericPipe.is_death_packet(data):
                     self._kill(data)
                     return
-                processed = self.perform_task(data)
-                self.dispatch_to_next(processed)
+                processed = self._perform_task(data)
+                self._send_to_next(processed)
             except Exception as e:
-                self._kill(GenericPipe.get_kill_word())
+                if str(e.__class__) == "<class '_queue.Empty'>":
+                    continue
+                self._kill(GenericPipe.get_kill_word(), True)
                 print(f"Error_{e.__class__.__name__}_{e.args}")
                 return
