@@ -11,5 +11,5 @@ class TaskPipe(GenericPipe[R, S]):
         super().__init__(source, target)
         self._task = task
 
-    def perform_task(self, data: R) -> S:
+    def _perform_task(self, data: R) -> S:
         return self._task(data)
